@@ -1,6 +1,6 @@
 /*
     YAGF - cuneiform and tesseract OCR graphical front-end
-    Copyright (C) 2009-2012 Andrei Borovsky <anb@symmetrica.net>
+    Copyright (C) 2009-2013 Andrei Borovsky <anb@symmetrica.net>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -29,6 +29,7 @@
 #include "tpagecollection.h"
 #include "scanner.h"
 #include "projectmanager.h"
+#include "forcelocaledialog.h"
 #include <signal.h>
 #include <QComboBox>
 #include <QLabel>
@@ -204,6 +205,9 @@ MainForm::MainForm(QWidget *parent): QMainWindow(parent)
     pdfPD.setWindowIcon(QIcon(":/yagf.png"));
     if (pdfx)
         connect(&pdfPD, SIGNAL(canceled()), pdfx, SLOT(cancel()));
+
+    menu_Settings->addAction("UI Language", this, SLOT(setUILanguage()));
+
 }
 
 void MainForm::onShowWindow()
@@ -428,8 +432,6 @@ void MainForm::decreaseButtonClicked()
 void MainForm::initSettings()
 {
     settings = Settings::instance();
-    settings->readSettings(settings->workingDir());
-    settings->writeSettings();
     if (settings->getFullScreen())
         showFullScreen();
     else {
@@ -623,7 +625,7 @@ void MainForm::showAboutDlg()
 {
     QPixmap icon;
     icon.load(":/yagf.png");
-    QMessageBox aboutBox(QMessageBox::NoIcon, trUtf8("About YAGF"), trUtf8("<p align=\"center\"><b>YAGF - Yet Another Graphical Front-end for cuneiform and tesseract OCR engines</b></p><p align=\"center\">Version %1</p> <p align=\"center\">Ⓒ 2009-2012 Andrei Borovsky</p> This is a free software distributed under GPL v3. Visit <a href=\"http://symmetrica.net/cuneiform-linux/yagf-en.html\">http://symmetrica.net/cuneiform-linux/yagf-en.html</a> for more details.").arg(version), QMessageBox::Ok);
+    QMessageBox aboutBox(QMessageBox::NoIcon, trUtf8("About YAGF"), trUtf8("<p align=\"center\"><b>YAGF - Yet Another Graphical Front-end for cuneiform and tesseract OCR engines</b></p><p align=\"center\">Version %1</p> <p align=\"center\">Ⓒ 2009-2013 Andrei Borovsky</p> This is a free software distributed under GPL v3. Visit <a href=\"http://symmetrica.net/cuneiform-linux/yagf-en.html\">http://symmetrica.net/cuneiform-linux/yagf-en.html</a> for more details.").arg(version), QMessageBox::Ok);
     aboutBox.setIconPixmap(icon);
     QList<QLabel *> labels = aboutBox.findChildren<QLabel *>();
     for (int i = 0; i < labels.count(); i++) {
@@ -1073,3 +1075,27 @@ void MainForm::selectHTMLformat()
     settings->setOutputFormat("text");
 
 }
+
+void MainForm::setUILanguage()
+{
+    ForceLocaleDialog fld(this);
+    if (settings->useNoLocale())
+        fld.setOption(ForceLocaleDialog::NoLocale);
+    else {
+        if (settings->useRussianLocale())
+            fld.setOption(ForceLocaleDialog::RussianLocale);
+        else {
+            fld.setOption(ForceLocaleDialog::DefaultLocale);
+        }
+    }
+    if (fld.exec() == QDialog::Accepted) {
+        settings->setNoLocale(false);
+        settings->setRussianLocale(false);
+        if (fld.getOption() == ForceLocaleDialog::NoLocale)
+            settings->setNoLocale(true);
+        else {
+            if (fld.getOption() == ForceLocaleDialog::RussianLocale)
+                settings->setRussianLocale(true);
+        }
+    }
+}
