@@ -471,10 +471,6 @@ The page possibly lacks contrast. Try to select blocks manually.</source>
         <source>Prepare Page</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Prepare the page for recognitoin</source>
-        <translation>Подготовить страницу к распознаванию</translation>
-    </message>
     <message>
         <source>Save Project...</source>
         <translation>Сохранить проект...</translation>
@@ -483,6 +479,10 @@ The page possibly lacks contrast. Try to select blocks manually.</source>
         <source>Load Project...</source>
         <translation>Загрузить проект...</translation>
     </message>
+    <message>
+        <source>Prepare the page for recognition</source>
+        <translation type="unfinished">Подготовить страницу для распознавания</translation>
+    </message>
 </context>
 <context>
     <name>PopplerDialog</name>
